@@ -1,4 +1,5 @@
 from copy import copy
+from classytags.compat import compat_basestring
 import re
 
 
@@ -15,7 +16,7 @@ class TemplateConstant(object):
     """
     def __init__(self, value):
         self.literal = value
-        if isinstance(value, basestring):
+        if isinstance(value, compat_basestring):
             self.value = value.strip('"\'')
         else:
             self.value = value
@@ -31,10 +32,12 @@ class StructuredOptions(object):
     """
     Bootstrapped options
     """
-    def __init__(self, options, breakpoints, blocks):
+    def __init__(self, options, breakpoints, blocks, combind_breakpoints):
         self.options = options
         self.breakpoints = copy(breakpoints)
         self.blocks = copy(blocks)
+        self.combined_breakpoints = dict(combind_breakpoints.items())
+        self.reversed_combined_breakpoints = dict((v,k) for k,v in combind_breakpoints.items())
         self.current_breakpoint = None
         if self.breakpoints:
             self.next_breakpoint = self.breakpoints.pop(0)
